@@ -12,18 +12,10 @@ Usage::
     session_client: SecretsManagerClient = session.client("secretsmanager")
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
-from __future__ import annotations
-
 import sys
-from typing import Any, Dict, IO, List, Union, overload
-from botocore.client import BaseClient
+from typing import Any, Dict, IO, List, TYPE_CHECKING, Union, overload
 from botocore.exceptions import ClientError as Boto3ClientError
-
-# pylint: disable=import-self
-import mypy_boto3_secretsmanager.client as client_scope
-
-# pylint: disable=import-self
-import mypy_boto3_secretsmanager.paginator as paginator_scope
+from mypy_boto3_secretsmanager.paginator import ListSecretsPaginator
 from mypy_boto3_secretsmanager.type_defs import (
     CancelRotateSecretResponseTypeDef,
     CreateSecretResponseTypeDef,
@@ -54,21 +46,36 @@ else:
 __all__ = ("SecretsManagerClient",)
 
 
-class SecretsManagerClient(BaseClient):
+class Exceptions:
+    ClientError: Boto3ClientError
+    DecryptionFailure: Boto3ClientError
+    EncryptionFailure: Boto3ClientError
+    InternalServiceError: Boto3ClientError
+    InvalidNextTokenException: Boto3ClientError
+    InvalidParameterException: Boto3ClientError
+    InvalidRequestException: Boto3ClientError
+    LimitExceededException: Boto3ClientError
+    MalformedPolicyDocumentException: Boto3ClientError
+    PreconditionNotMetException: Boto3ClientError
+    ResourceExistsException: Boto3ClientError
+    ResourceNotFoundException: Boto3ClientError
+
+
+class SecretsManagerClient:
     """
-    [SecretsManager.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.48/reference/services/secretsmanager.html#SecretsManager.Client)
+    [SecretsManager.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.12/reference/services/secretsmanager.html#SecretsManager.Client)
     """
 
-    exceptions: client_scope.Exceptions
+    exceptions: Exceptions
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.48/reference/services/secretsmanager.html#SecretsManager.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.12/reference/services/secretsmanager.html#SecretsManager.Client.can_paginate)
         """
 
     def cancel_rotate_secret(self, SecretId: str) -> CancelRotateSecretResponseTypeDef:
         """
-        [Client.cancel_rotate_secret documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.48/reference/services/secretsmanager.html#SecretsManager.Client.cancel_rotate_secret)
+        [Client.cancel_rotate_secret documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.12/reference/services/secretsmanager.html#SecretsManager.Client.cancel_rotate_secret)
         """
 
     def create_secret(
@@ -82,12 +89,12 @@ class SecretsManagerClient(BaseClient):
         Tags: List[TagTypeDef] = None,
     ) -> CreateSecretResponseTypeDef:
         """
-        [Client.create_secret documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.48/reference/services/secretsmanager.html#SecretsManager.Client.create_secret)
+        [Client.create_secret documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.12/reference/services/secretsmanager.html#SecretsManager.Client.create_secret)
         """
 
     def delete_resource_policy(self, SecretId: str) -> DeleteResourcePolicyResponseTypeDef:
         """
-        [Client.delete_resource_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.48/reference/services/secretsmanager.html#SecretsManager.Client.delete_resource_policy)
+        [Client.delete_resource_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.12/reference/services/secretsmanager.html#SecretsManager.Client.delete_resource_policy)
         """
 
     def delete_secret(
@@ -97,12 +104,12 @@ class SecretsManagerClient(BaseClient):
         ForceDeleteWithoutRecovery: bool = None,
     ) -> DeleteSecretResponseTypeDef:
         """
-        [Client.delete_secret documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.48/reference/services/secretsmanager.html#SecretsManager.Client.delete_secret)
+        [Client.delete_secret documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.12/reference/services/secretsmanager.html#SecretsManager.Client.delete_secret)
         """
 
     def describe_secret(self, SecretId: str) -> DescribeSecretResponseTypeDef:
         """
-        [Client.describe_secret documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.48/reference/services/secretsmanager.html#SecretsManager.Client.describe_secret)
+        [Client.describe_secret documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.12/reference/services/secretsmanager.html#SecretsManager.Client.describe_secret)
         """
 
     def generate_presigned_url(
@@ -113,7 +120,7 @@ class SecretsManagerClient(BaseClient):
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.48/reference/services/secretsmanager.html#SecretsManager.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.12/reference/services/secretsmanager.html#SecretsManager.Client.generate_presigned_url)
         """
 
     def get_random_password(
@@ -128,19 +135,19 @@ class SecretsManagerClient(BaseClient):
         RequireEachIncludedType: bool = None,
     ) -> GetRandomPasswordResponseTypeDef:
         """
-        [Client.get_random_password documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.48/reference/services/secretsmanager.html#SecretsManager.Client.get_random_password)
+        [Client.get_random_password documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.12/reference/services/secretsmanager.html#SecretsManager.Client.get_random_password)
         """
 
     def get_resource_policy(self, SecretId: str) -> GetResourcePolicyResponseTypeDef:
         """
-        [Client.get_resource_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.48/reference/services/secretsmanager.html#SecretsManager.Client.get_resource_policy)
+        [Client.get_resource_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.12/reference/services/secretsmanager.html#SecretsManager.Client.get_resource_policy)
         """
 
     def get_secret_value(
         self, SecretId: str, VersionId: str = None, VersionStage: str = None
     ) -> GetSecretValueResponseTypeDef:
         """
-        [Client.get_secret_value documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.48/reference/services/secretsmanager.html#SecretsManager.Client.get_secret_value)
+        [Client.get_secret_value documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.12/reference/services/secretsmanager.html#SecretsManager.Client.get_secret_value)
         """
 
     def list_secret_version_ids(
@@ -151,21 +158,21 @@ class SecretsManagerClient(BaseClient):
         IncludeDeprecated: bool = None,
     ) -> ListSecretVersionIdsResponseTypeDef:
         """
-        [Client.list_secret_version_ids documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.48/reference/services/secretsmanager.html#SecretsManager.Client.list_secret_version_ids)
+        [Client.list_secret_version_ids documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.12/reference/services/secretsmanager.html#SecretsManager.Client.list_secret_version_ids)
         """
 
     def list_secrets(
         self, MaxResults: int = None, NextToken: str = None
     ) -> ListSecretsResponseTypeDef:
         """
-        [Client.list_secrets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.48/reference/services/secretsmanager.html#SecretsManager.Client.list_secrets)
+        [Client.list_secrets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.12/reference/services/secretsmanager.html#SecretsManager.Client.list_secrets)
         """
 
     def put_resource_policy(
         self, SecretId: str, ResourcePolicy: str
     ) -> PutResourcePolicyResponseTypeDef:
         """
-        [Client.put_resource_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.48/reference/services/secretsmanager.html#SecretsManager.Client.put_resource_policy)
+        [Client.put_resource_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.12/reference/services/secretsmanager.html#SecretsManager.Client.put_resource_policy)
         """
 
     def put_secret_value(
@@ -177,12 +184,12 @@ class SecretsManagerClient(BaseClient):
         VersionStages: List[str] = None,
     ) -> PutSecretValueResponseTypeDef:
         """
-        [Client.put_secret_value documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.48/reference/services/secretsmanager.html#SecretsManager.Client.put_secret_value)
+        [Client.put_secret_value documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.12/reference/services/secretsmanager.html#SecretsManager.Client.put_secret_value)
         """
 
     def restore_secret(self, SecretId: str) -> RestoreSecretResponseTypeDef:
         """
-        [Client.restore_secret documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.48/reference/services/secretsmanager.html#SecretsManager.Client.restore_secret)
+        [Client.restore_secret documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.12/reference/services/secretsmanager.html#SecretsManager.Client.restore_secret)
         """
 
     def rotate_secret(
@@ -193,17 +200,17 @@ class SecretsManagerClient(BaseClient):
         RotationRules: RotationRulesTypeTypeDef = None,
     ) -> RotateSecretResponseTypeDef:
         """
-        [Client.rotate_secret documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.48/reference/services/secretsmanager.html#SecretsManager.Client.rotate_secret)
+        [Client.rotate_secret documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.12/reference/services/secretsmanager.html#SecretsManager.Client.rotate_secret)
         """
 
     def tag_resource(self, SecretId: str, Tags: List[TagTypeDef]) -> None:
         """
-        [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.48/reference/services/secretsmanager.html#SecretsManager.Client.tag_resource)
+        [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.12/reference/services/secretsmanager.html#SecretsManager.Client.tag_resource)
         """
 
     def untag_resource(self, SecretId: str, TagKeys: List[str]) -> None:
         """
-        [Client.untag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.48/reference/services/secretsmanager.html#SecretsManager.Client.untag_resource)
+        [Client.untag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.12/reference/services/secretsmanager.html#SecretsManager.Client.untag_resource)
         """
 
     def update_secret(
@@ -216,7 +223,7 @@ class SecretsManagerClient(BaseClient):
         SecretString: str = None,
     ) -> UpdateSecretResponseTypeDef:
         """
-        [Client.update_secret documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.48/reference/services/secretsmanager.html#SecretsManager.Client.update_secret)
+        [Client.update_secret documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.12/reference/services/secretsmanager.html#SecretsManager.Client.update_secret)
         """
 
     def update_secret_version_stage(
@@ -227,28 +234,11 @@ class SecretsManagerClient(BaseClient):
         MoveToVersionId: str = None,
     ) -> UpdateSecretVersionStageResponseTypeDef:
         """
-        [Client.update_secret_version_stage documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.48/reference/services/secretsmanager.html#SecretsManager.Client.update_secret_version_stage)
+        [Client.update_secret_version_stage documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.12/reference/services/secretsmanager.html#SecretsManager.Client.update_secret_version_stage)
         """
 
     @overload
-    def get_paginator(
-        self, operation_name: Literal["list_secrets"]
-    ) -> paginator_scope.ListSecretsPaginator:
+    def get_paginator(self, operation_name: Literal["list_secrets"]) -> ListSecretsPaginator:
         """
-        [Paginator.ListSecrets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.48/reference/services/secretsmanager.html#SecretsManager.Paginator.ListSecrets)
+        [Paginator.ListSecrets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.12/reference/services/secretsmanager.html#SecretsManager.Paginator.ListSecrets)
         """
-
-
-class Exceptions:
-    ClientError: Boto3ClientError
-    DecryptionFailure: Boto3ClientError
-    EncryptionFailure: Boto3ClientError
-    InternalServiceError: Boto3ClientError
-    InvalidNextTokenException: Boto3ClientError
-    InvalidParameterException: Boto3ClientError
-    InvalidRequestException: Boto3ClientError
-    LimitExceededException: Boto3ClientError
-    MalformedPolicyDocumentException: Boto3ClientError
-    PreconditionNotMetException: Boto3ClientError
-    ResourceExistsException: Boto3ClientError
-    ResourceNotFoundException: Boto3ClientError
